@@ -2,7 +2,7 @@ package Minilla;
 use strict;
 use warnings;
 use 5.008005;
-use version; our $VERSION = version->declare("v2.4.4");
+use version; our $VERSION = version->declare("v2.5.0");
 
 our $DEBUG;
 our $AUTO_INSTALL;
@@ -36,15 +36,19 @@ Minilla is a CPAN module authoring tool. Minilla provides L<minil> command for a
 
     (M::I - inc) + shipit + (dzil - plugins)
 
+B<THIS IS A DEVELOPMENT RELEASE. API MAY CHANGE WITHOUT NOTICE>.
+
+=head1 MOTIVATION
+
 =head1 CONVENTION
 
 As stated above, Minilla is opinionated. Minilla has a bold assumption and convention like the followings, which are almost compatible to the sister project L<Dist::Milla>.
 
 =over 4
 
-=item Your modules are written in Pure Perl and are located in I<lib/>.
+=item Your module written in Pure Perl are located in I<lib/>.
 
-=item Your executable files are in I<script/> directory, if any
+=item Your executable file is in I<script/> directory, if any
 
 =item Your module is maintained with B<Git> and C<git ls-files> matches with what you will release
 
@@ -52,8 +56,6 @@ As stated above, Minilla is opinionated. Minilla has a bold assumption and conve
 
 =item Your module has a Changes file
 
-=item Your module requires at least perl 5.6.
-
 =back
 
 =head1 GETTING STARTED
@@ -365,7 +367,7 @@ Is there a reason to remove ppport.h from repo?
 
 =item How can I install script files?
 
-Your executables must be in F<script/> directory.
+Your executables must be in F<script/>. It's L<Module::Build::Tiny>'s rule.
 
 =item How to switch from Module::Install/Module::Build/Dist::Zilla?
 
@@ -380,24 +382,23 @@ You can use MANIFEST.SKIP file for ignoring files. ref. L<ExtUtils::Manifest>.
 
 =item How do I use Module::Build::Tiny with Minilla?
 
-Minilla supports Module::Build::Tiny and uses it as a default installer since v1.0.0.
+Minilla v0.15.0+ supports v0.15.0(EXPERIMENTAL).
 
-If you want to migrate an existing project created before Minilla v1.0, you need to rewrite C<minil.toml> file.
-You need to add the following line:
+If you want to create new project with Module::Build::Tiny, run the command as following.
+
+    % minil new -p ModuleBuildTiny My::Awesome::Module
+
+If you want to migrate existing project, you need to rewrite minil.toml file.
+You need to add following line:
 
     module_maker="ModuleBuildTiny"
 
-=item How do I use Module::Build with Minilla?
-
-If you want to create new project with Module::Build, run the command as following.
-
-    % minil new -p ModuleBuild My::Awesome::Module
-
 =item How do I use ExtUtils::MakeMaker with Minilla?
 
 Minilla v2.1.0+ supports EUMM(EXPERIMENTAL).
 
-You need to rewrite minil.toml file and add the following line:
+You need to rewrite minil.toml file.
+You need to add following line:
 
     module_maker="ExtUtilsMakeMaker"
 
@@ -406,12 +407,6 @@ You need to rewrite minil.toml file and add the following line:
 I don't suggest to use this module... But you can use this option for maintaining
 primitive modules like Test::TCP.
 
-=item Ho do I support Perl 5.6?
-
-EUMM can run on Perl 5.6. Write following statement in your minil.toml file.
-
-    module_maker="ExtUtilsMakeMaker"
-
 =back
 
 =head1 AUTHORS
